import {Component, Input} from '@angular/core';
import {Recipe} from "../../../shared/model/recipe.model";
import {SubscribingComponent} from "../../../shared/components/subscribing.component";
import {ActivatedRoute, Router} from "@angular/router";
import {Observable} from "rxjs";
import {RecipeImageService} from "../../services/recipe-image.service";
import {environment} from "../../../../../environments/environment";

@Component({
  selector: 'cre-images-editor',
  templateUrl: './images-editor.component.html',
  styleUrls: ['./images-editor.component.sass']
})
export class ImagesEditorComponent extends SubscribingComponent {
  @Input() recipe: Recipe
  @Input() editionMode = false

  imageIds$: Observable<number[]>
  backendUrl = environment.apiUrl

  constructor(
    private recipeImageService: RecipeImageService,
    router: Router,
    activatedRoute: ActivatedRoute
  ) {
    super(activatedRoute, router)
  }

  ngOnInit() {
    super.ngOnInit()

    this.loadImagesIds()
  }

  submit(event) {
    const image = event.target.files[0]
    this.subscribe(
      this.recipeImageService.save(image, this.recipe.id),
      {next: () => this.loadImagesIds()}
    )
  }

  openImage(imageId: number) {
    window.open(`${environment.apiUrl}/recipe/${this.recipe.id}/image/${imageId}`, '_blank')
  }

  delete(imageId: number) {
    this.subscribe(
      this.recipeImageService.delete(imageId, this.recipe.id),
      {next: () => this.loadImagesIds()}
    )
  }

  private loadImagesIds() {
    this.imageIds$ = this.recipeImageService.getAllIdsForRecipe(this.recipe.id)
  }
}
